@@ -10,6 +10,7 @@
 #include "libarchiveplugin.h"
 #include "ark_debug.h"
 #include "queries.h"
+#include "windows_stat.h"
 
 #include <KLocalizedString>
 
@@ -115,6 +116,13 @@ bool LibarchivePlugin::list()
 
     if (result != ARCHIVE_EOF) {
         qCCritical(ARK) << "Error while reading archive:" << result << QLatin1String(archive_error_string(m_archiveReader.data()));
+        // libarchive currently doesn't support header-encrypted 7zip archives, but doesn't clearly tells when that happens.
+        // It just returns a generic ARCHIVE_FATAL when calling the archive_read_next_header function.
+        // If there are 0 detected entries, this is likely a header-encrypted archive, but we can't be 100& sure.
+        if (archive_format(m_archiveReader.data()) == ARCHIVE_FORMAT_7ZIP && m_cachedArchiveEntryCount == 0) {
+            Q_EMIT error(i18nc("@info", "The archive may be corrupt or has header-encryption, which is currently not supported."));
+            return false;
+        }
         if (!emitCorruptArchive()) {
             return false;
         }
@@ -182,7 +190,7 @@ void LibarchivePlugin::copyDataBlock(const QString &filename, archive *source, a
     }
 }
 
-bool LibarchivePlugin::addFiles(const QVector<Archive::Entry *> &files,
+bool LibarchivePlugin::addFiles(const QList<Archive::Entry *> &files,
                                 const Archive::Entry *destination,
                                 const CompressionOptions &options,
                                 uint numberOfEntriesToAdd)
@@ -194,7 +202,7 @@ bool LibarchivePlugin::addFiles(const QVector<Archive::Entry *> &files,
     return false;
 }
 
-bool LibarchivePlugin::moveFiles(const QVector<Archive::Entry *> &files, Archive::Entry *destination, const CompressionOptions &options)
+bool LibarchivePlugin::moveFiles(const QList<Archive::Entry *> &files, Archive::Entry *destination, const CompressionOptions &options)
 {
     Q_UNUSED(files)
     Q_UNUSED(destination)
@@ -202,7 +210,7 @@ bool LibarchivePlugin::moveFiles(const QVector<Archive::Entry *> &files, Archive
     return false;
 }
 
-bool LibarchivePlugin::copyFiles(const QVector<Archive::Entry *> &files, Archive::Entry *destination, const CompressionOptions &options)
+bool LibarchivePlugin::copyFiles(const QList<Archive::Entry *> &files, Archive::Entry *destination, const CompressionOptions &options)
 {
     Q_UNUSED(files)
     Q_UNUSED(destination)
@@ -210,7 +218,7 @@ bool LibarchivePlugin::copyFiles(const QVector<Archive::Entry *> &files, Archive
     return false;
 }
 
-bool LibarchivePlugin::deleteFiles(const QVector<Archive::Entry *> &files)
+bool LibarchivePlugin::deleteFiles(const QList<Archive::Entry *> &files)
 {
     Q_UNUSED(files)
     return false;
@@ -237,7 +245,7 @@ bool LibarchivePlugin::doKill()
     return false;
 }
 
-bool LibarchivePlugin::extractFiles(const QVector<Archive::Entry *> &files, const QString &destinationDirectory, const ExtractionOptions &options)
+bool LibarchivePlugin::extractFiles(const QList<Archive::Entry *> &files, const QString &destinationDirectory, const ExtractionOptions &options)
 {
     if (!initializeReader()) {
         return false;
@@ -307,6 +315,12 @@ bool LibarchivePlugin::extractFiles(const QVector<Archive::Entry *> &files, cons
             continue;
         }
 
+        // Skip encrypted 7-zip entries, since libarchive cannot extract them yet.
+        if (archive_format(m_archiveReader.data()) == ARCHIVE_FORMAT_7ZIP && archive_entry_is_data_encrypted(entry)) {
+            archive_read_data_skip(m_archiveReader.data());
+            continue;
+        }
+
         // entryName is the name inside the archive, full path
         QString entryName = QDir::fromNativeSeparators(QFile::decodeName(archive_entry_pathname(entry)));
         if (archive_format(m_archiveReader.data()) == ARCHIVE_FORMAT_RAW) {
@@ -481,6 +495,13 @@ bool LibarchivePlugin::extractFiles(const QVector<Archive::Entry *> &files, cons
         }
     }
 
+    // If nothing was extracted, the entries must have been all encrypted.
+    if (extractedEntriesCount == 0 && archive_format(m_archiveReader.data()) == ARCHIVE_FORMAT_7ZIP
+        && archive_read_has_encrypted_entries(m_archiveReader.data())) {
+        Q_EMIT error(i18nc("@info", "Extraction of encrypted 7-zip entries is currenty not supported."));
+        return false;
+    }
+
     qCDebug(ARK) << "Extracted" << extractedEntriesCount << "entries";
     slotRestoreWorkingDir();
     return archive_read_close(m_archiveReader.data()) == ARCHIVE_OK;
@@ -523,12 +544,7 @@ bool LibarchivePlugin::initializeReader()
 void LibarchivePlugin::emitEntryFromArchiveEntry(struct archive_entry *aentry, bool isRawFormat)
 {
     auto e = new Archive::Entry();
-
-#ifdef Q_OS_WIN
-    e->setProperty("fullPath", QDir::fromNativeSeparators(QString::fromUtf16((ushort *)archive_entry_pathname_w(aentry))));
-#else
     e->setProperty("fullPath", QDir::fromNativeSeparators(QString::fromWCharArray(archive_entry_pathname_w(aentry))));
-#endif
 
     if (isRawFormat) {
         e->setProperty("displayName",
@@ -536,6 +552,10 @@ void LibarchivePlugin::emitEntryFromArchiveEntry(struct archive_entry *aentry, b
         e->setProperty("compressedSize", QFileInfo(filename()).size());
         e->compressedSizeIsSet = true;
     } else {
+        if (archive_entry_is_encrypted(aentry)) {
+            e->setProperty("isPasswordProtected", true);
+        }
+
         const QString owner = QString::fromLatin1(archive_entry_uname(aentry));
         if (!owner.isEmpty()) {
             e->setProperty("owner", owner);
